pydevDAG._readwrite._write module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »

# pydevDAG._readwrite._write module

## pydevDAG._readwrite._write

Tools to modify a graph for caching.

class `pydevDAG._readwrite._write.` `DefaultRewriters`

  Bases: `object`

  Generates the most likely rewriter for nodes.

  static `rewrite_edge_gen`(graph, edge, key, func)

    Default way of rewriting an edge.

    Assumes that the key and value are at the top level.

    Parameters: | graph – the graph edge – a single edge key (str) – the key of the graph attribute func (object -> object) – the func that gives new value for attribute value

  static `rewrite_node_gen`(graph, node, key, func)

    Default way of rewriting a node.

    Assumes that the key and value are at the top level.

    Parameters: | graph – the graph node – a single node key (str) – the key of the graph attribute func (object -> object) – the func that gives new value for attribute value

class `pydevDAG._readwrite._write.` `DevlinkRewriter`

  Bases: `pydevDAG._readwrite._write.ElementRewriter`

  Rewrites device links attributes.

  static `destringize`(graph, node)
  static `stringize`(graph, node)

class `pydevDAG._readwrite._write.` `EdgeDiffStatusRewriter`

  Bases: `pydevDAG._readwrite._write.ElementRewriter`

  Rewrites edge diff status.

  static `destringize`(graph, edge)
  static `stringize`(graph, edge)

class `pydevDAG._readwrite._write.` `EdgeTypeRewriter`

  Bases: `pydevDAG._readwrite._write.ElementRewriter`

  Rewrites edge type.

  static `destringize`(graph, edge)
  static `stringize`(graph, edge)

class `pydevDAG._readwrite._write.` `ElementRewriter`

  Bases: `object`

  Generic interface of an element rewriter.

  static `destringize`(graph, ele)

    Inverse of stringize.

    Parameters: | ele – a graph element

  static `stringize`(graph, ele)

    Convert attributes of this element to strings.

    Parameters: | ele – a graph element

class `pydevDAG._readwrite._write.` `NodeDiffStatusRewriter`

  Bases: `pydevDAG._readwrite._write.ElementRewriter`

  Rewrites node diff status.

  static `destringize`(graph, node)
  static `stringize`(graph, node)

class `pydevDAG._readwrite._write.` `NodeTypeRewriter`

  Bases: `pydevDAG._readwrite._write.ElementRewriter`

  Rewrites node type.

  static `destringize`(graph, node)
  static `stringize`(graph, node)

class `pydevDAG._readwrite._write.` `Rewriter`

  Bases: `object`

  Rewrite graph for output.

  classmethod `destringize`(graph)

    Xform objects in graph to strings as necessary. :param graph: the graph

  classmethod `stringize`(graph)

    Xform objects in graph to strings as necessary. :param graph: the graph

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._readwrite package »